/**
 * Change controller with undo functionality.
 * 
 * Capabilities:
 * -change
 * -undo
 * -set
 * -get
 * -has
 * -unset
 * -continue
 * -continued
 * 
 * Choices are inherently unsettable.
 * This class offers change undo functionality.
 * A full choice undo requires calling both the unset as well as the undo function.
 * @param {string} id Id of the scene.
 * @param {string} key Key of this choice.
 * @param {function} changeFn Change function, called once.
 * @param {function} changeNoteFn Change note function. Should return a global.ui.change.buildNotification() result.
 * @param {function} undoFn Undo change function. Should undo everything done in the change function.
 */
function UndoController(id, key, changeFn, changeNoteFn, undoFn) {
    ChangeController.call(this, id, key, changeFn, changeNoteFn, undoFn);
    this.undo = function () {
        var changeId = key + "Change";
        if (global.kobold.history.has(id, changeId)) {
            global.kobold.history.unsetKey(id, changeId);
            undoFn();
        }
    };
}
