/**
 * The HeartyMeal class represents a meal that can be consumed by the kobold,
 * which increases its statuses.
 */
function HeartyMeal() {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;

    var itemName = "Hearty Meal";
    var itemDescription = "A basket containing bread, meat, some cheese and a small drink of water. An entire meal to go.";
    var baseValue = 12;

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    /**
     * Builds and returns the consume popup contents.
     * @returns {string} The consume popup contents.
     */
    function buildPopupContents() {
        var content = ` [st]${itemName}[/st]
                        [p]
                            You open up the small basket, and fetch out a loaf of bread,
                            on which you put a slice of cheese and a slice of ham.
                            You take a moment to eagerly lick your lips.
                            The sandwich you just made is quite a feast compared to what you usually eat.
                            And you don't intend to let any of it go to waste.
                        [/p]
                        [p]
                            You bite down and tear off an entire mouthful of the delicious mixture of meat, cheese and bread.
                            The flavor, while ordinary to most people who are [i]used[/i] to eating regular food,
                            is absolutely [b]divine[/b] to a kobold like yourself who's used to eating garbage,
                            dead animals left behind by hunters and whatever fish you manage to catch in the river.
                        [/p]
                        [p]
                            After a few more big bites, the appetizing sandwich is, sadly enough, all gone.
                            You swallow the final mouthful, before reaching into the basket once more, this time fetching the small bottle of water.
                            Gulping the cool liquid down, you clear the insides of your muzzle of any remaining bits and pieces of food.
                        [/p]
                        [p]
                            You've had a very nice meal, which has left you feeling much better than before.
                            You contently rub your well-filled stomach, and with a smile on your face,
                            you prepare yourself to continue your adventure.
                        [/p]`;
        return global.parser.parse(content);
    }

    // PUBLIC MEMBERS \\        this.public = "test";

    // ITEM-REQUIRED item-enum for construction purposes.
    this.id = ItemEnum.HEARTY_MEAL;
    // ITEM-REQUIRED type-enum for tooltip purposes.
    this.type = ItemTypeEnum.CONSUMABLE;

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * ITEM-REQUIRED function.
     * Builds and returns the name of this item.
     * @param {boolean} caps Whether or not the name should be capitalized.
     * @returns {string} The name of this item.
     */
    this.name = function (caps) {
        var toReturn = caps ? itemName : itemName.toLowerCase();
        return toReturn;
    };

    /**
     * ITEM-REQUIRED function.
     * Builds and returns the description of this item.
     * @returns {string} The description of this item.
     */
    this.description = function () {
        return itemDescription;
    };

    /**
     * ITEM-REQUIRED function.
     * Calculates and returns the price (= value) of this item.
     * @returns {int} The price of this pair of pants, in coins.
     */
    this.price = function () {
        return baseValue;
    };

    /**
     * ITEM-REQUIRED function.
     * Builds and returns a custom tooltip style for this item.
     * @returns {string} The custom style.
     */
    this.toolTipStyle = function () {
        return "width: 180px;";
    };

    /**
     * CONSUMABLE-REQUIRED function.
     * Consumes this consumable.
     */
    this.consume = function () {
        global.kobold.status.physical.increase(10, "Ate a hearty meal");
        global.kobold.status.mental.increase(10, "Ate a hearty meal");
        global.kobold.status.stamina.increase(10, "Ate a hearty meal");
        global.kobold.status.exertion.decrease(10, "Ate a hearty meal");
        var contents = buildPopupContents();
        contents += global.ui.change.buildNotification([
            new Change("Food", "Health", +10), 
            new Change("Food", "Sanity", +10),
            new Change("Food", "Stamina", +10),
            new Change("Food", "Sexual exhaustion", -10, true)
        ]);
        global.ui.showFullscreenPopup(contents);
    };

    /**
     * ITEM-REQUIRED function.
     * Loads this object from a type-stripped version thereof.
     * @param {AgilityPotion-stripped} potion An AgilityPotion object, stripped of private members and all functions.
     */
    this.load = function (potion) {

    };
}
