/**
 * The TeaBiscuit class represents a biscuit that can be consumed by the kobold,
 * which increases its statuses.
 */
function TeaBiscuit() {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;

    var itemName = "Tea Biscuit";
    var itemDescription = "A delicious, sugary treat. Usually consumed while drinking hot beverages, but good to eat on its own as well.";
    var baseValue = 6;

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    /**
     * Builds and returns the consume popup contents.
     * @returns {string} The consume popup contents.
     */
    function buildPopupContents() {
        var content = ` [st]${itemName}[/st]
                        [p]
                            You bring the vanilla biscuit to your muzzle,
                            its delightful scent reaching your nostrils long before the crunchy goodness itself passes your lips.
                            You bite off over half of the cookie in one go, its delectable flavor spreading across your tastebuds.
                            Yummy!
                        [/p]
                        [p]
                            Sadly, it's a rather small wafer.
                            Small enough that after your initial bite, you can fit the entirety of the rest into your mouth.
                            After a bit of chewing and subsequent swallowing, the biscuit's all gone, but luckily, its taste lingers for a few minutes more.
                        [/p]`;
        return global.parser.parse(content);
    }

    // PUBLIC MEMBERS \\        this.public = "test";

    // ITEM-REQUIRED item-enum for construction purposes.
    this.id = ItemEnum.TEA_BISCUIT;
    // ITEM-REQUIRED type-enum for tooltip purposes.
    this.type = ItemTypeEnum.CONSUMABLE;

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * ITEM-REQUIRED function.
     * Builds and returns the name of this item.
     * @param {boolean} caps Whether or not the name should be capitalized.
     * @returns {string} The name of this item.
     */
    this.name = function (caps) {
        var toReturn = caps ? itemName : itemName.toLowerCase();
        return toReturn;
    };

    /**
     * ITEM-REQUIRED function.
     * Builds and returns the description of this item.
     * @returns {string} The description of this item.
     */
    this.description = function () {
        return itemDescription;
    };

    /**
     * ITEM-REQUIRED function.
     * Calculates and returns the price (= value) of this item.
     * @returns {int} The price of this pair of pants, in coins.
     */
    this.price = function () {
        return baseValue;
    };

    /**
     * ITEM-REQUIRED function.
     * Builds and returns a custom tooltip style for this item.
     * @returns {string} The custom style.
     */
    this.toolTipStyle = function () {
        return "width: 210px;";
    };

    /**
     * CONSUMABLE-REQUIRED function.
     * Consumes this consumable.
     */
    this.consume = function () {
        global.kobold.status.physical.increase(5, "Ate a biscuit");
        global.kobold.status.mental.increase(5, "Ate a biscuit");
        global.kobold.status.stamina.increase(5, "Ate a biscuit");
        global.kobold.status.exertion.decrease(5, "Ate a biscuit");
        var contents = buildPopupContents();
        contents += global.ui.change.buildNotification([
            new Change("Food", "Health", +5), 
            new Change("Food", "Sanity", +5),
            new Change("Food", "Stamina", +5),
            new Change("Food", "Sexual exhaustion", -5, true)
        ]);
        global.ui.showFullscreenPopup(contents);
    };

    /**
     * ITEM-REQUIRED function.
     * Loads this object from a type-stripped version thereof.
     * @param {TeaBiscuit-stripped} food A TeaBiscuit object, stripped of private members and all functions.
     */
    this.load = function (food) {

    };
}
