/**
 * This class contains functions specific to the Scene tab.
 * Its init() function should be called immediately upon successful project load.
 * @param {GenericTab} generic An optional GenericTab to prevent having to create multiple copies.
 */
function SceneTab(generic) {
    // PRIVATE MEMBERS \\       var private = "test";
    var gen = generic ? generic : new GenericTab();
    var id = "scenetab";
    var mainId = "main";

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    /**
     * The onclick function for this tab.
     * Does nothing if the tab is already active.
     */
    function onClick() {
        if (gen.isActive(id)) {
            return;
        }
        gen.tabButtonTransition(id);
        global.sceneLoader.loadScene(id);
    }

    /**
     * The onscroll listener for the main window.
     * Updates the sceneScroll level of the UiController
     *   only when this tab is active.
     */
    function onScroll() {
        if (!gen.isActive(id)) {
            return;
        }
        var scroll = $("#" + mainId).scrollTop();
        global.ui.sceneScroll = scroll;
    }

    /**
     * Registers the onclick function for this tab.
     * Registers a scroll listener to the main window to update the sceneScroll.
     */
    function registerListeners() {
        $("#" + id).click(onClick);
        $("#" + mainId).scroll(onScroll);
    }

    // PUBLIC MEMBERS \\        this.public = "test";

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * Initializes this tab.
     * Registers the tab click listener.
     * Registers the tab with the scene loader.
     */
    this.init = function () {
        registerListeners();
        global.sceneLoader.registerScene(id, this);
    };

    /**
     * Loads this tab.
     */
    this.load = function () {
        global.sceneLoader.loadScene(global.currentScene);
        global.ui.setScroll();
    };

    /**
     * Activates this tab.
     * Only alters button visuals.
     */
    this.activate = function () {
        global.ui.imageBackground.hide();
        gen.tabButtonTransition(id);
    };
}
