/**
 * Controller for the Forest scene.
 * @param {string} sceneId The id of the scene.
 */
function ForestController(sceneId) {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;
    var id = sceneId;
    SceneController.call(this, id);

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    // PUBLIC MEMBERS \\        this.public = "test";
    this.intro = new ForestIntroductionController(id);
    this.home = new ForestHomeController(id);
    this.woods = new ForestWoodsController(id);
    this.bandit = new ForestBanditController(id);
    this.unknown = new ForestUnknownController(id);

    this.homeSceneName = "Home";
    this.enslaveSceneName = "CarriageNight";
    this.enslaveFolder = "Enslave";
    this.enslaveReady = false;

    this.misc = new MiscController(id);

    this.hide = new ChoiceController(id, "hide");
    this.tree = new ChangeController(id, "tree", function change() {
        global.kobold.status.physical.decrease(5, "Bee sting");
        global.kobold.status.stamina.decrease(10, "Tree climbing");
    }, function changeNote() {
        return global.ui.change.buildNotification([
            new Change("Got stung", "Health", -5),
            new Change("Tree climbing", "Stamina", -10)
        ]);
    });
    this.treeFail = new ChangeController(id, "treeFail", function change() {
        global.kobold.status.mental.decrease(10, "Panicking");
        global.kobold.status.stamina.decrease(10, "Attempted climbing");
    }, function changeNote() {
        return global.ui.change.buildNotification([
            new Change("Panic", "Sanity", -10),
            new Change("Attempted climbing", "Stamina", -10)
        ]);
    });
    this.bush = new ChangeController(id, "bush", function change() {
        global.kobold.status.mental.decrease(10, "Panicking");
    }, function changeNote() {
        return global.ui.change.buildNotification([
            new Change("Panic", "Sanity", -10)
        ]);
    });
    this.run = new ChoiceController(id, "run");
    this.runFail = new ChangeController(id, "runFail", function change() {
        global.kobold.status.physical.decrease(10, "Smacking into a branch");
        global.kobold.status.mental.decrease(20, "Getting caught");
        global.kobold.status.stamina.decrease(10, "Running");
    }, function changeNote() {
        return global.ui.change.buildNotification([
            new Change("Hit branch", "Health", -10),
            new Change("Caught", "Sanity", -10),
            new Change("Imminent rape", "Sanity", -10),
            new Change("Ran", "Stamina", -10)
        ]);
    });

    this.struggle = new ChoiceController(id, "runFailStruggle");

    this.preContinue = new ContinueController(id, "preContinue");

    this.treeThrow = new ChangeController(id, "treeThrow", function change() {
        global.kobold.status.physical.decrease(10, "Bee stings");
        global.kobold.status.mental.increase(10, "Outsmarting pursuers");
        global.kobold.status.stamina.decrease(15, "Running away");
    }, function changeNote() {
        return global.ui.change.buildNotification([
            new Change("Multiple stings", "Health", -10),
            new Change("Outsmarted pursuers", "Sanity", +10),
            new Change("Jumped down", "Stamina", -5),
            new Change("Ran away", "Stamina", -10)
        ]);
    });

    this.treeWeather = new ChangeController(id, "treeWeather", function change() {
        global.kobold.status.physical.decrease(50, "Hellish pain");
        global.kobold.status.mental.decrease(20, "Near death experience");
        global.kobold.stats.decreaseStat(StatsEnum.STRENGTH, 1);
    }, function changeNote() {
        return global.ui.change.buildNotification([
            new Change("Massive amounts of beestings", "Health", -30),
            new Change("Fell down tree", "Health", -20),
            new Change("Near death experience", "Sanity", -10),
            new Change("Traumatized", "Sanity", -10),
            new Change("Lasting effects", "Strength", -1)
        ]);
    });

    this.surrenderRock = new ChangeController(id, "surrenderRock", function change() {
        global.kobold.status.physical.decrease(20, "Rock insertion");
        global.kobold.status.mental.decrease(35, "Rock insertion");
        global.kobold.status.exertion.increase(15, "Rock insertion");
        global.kobold.inventory.coins -= that.misc.gold();
        if (that.misc.cunt()) {
            global.kobold.body.vaginalVirgin = false;
        } else {
            global.kobold.body.cockslitVirgin = false;
        }
    }, function changeNote() {
        return global.ui.change.buildNotification([
            new Change("Rock insertion", "Health", -20),
            new Change("Rock insertion", "Sanity", -35),
            new Change("Rock insertion", "Sexual exertion", +15, true),
            new Change("Money taken", "Gold", -that.misc.gold())
        ]);
    });

    this.surrenderSpank = new ChangeController(id, "surrenderSpank", function change() {
        global.kobold.status.physical.decrease(10, "Firmly spanked");
        global.kobold.status.mental.decrease(30, "Extreme humiliation");
        global.kobold.status.exertion.increase(5, "Hurting rear");
        global.kobold.inventory.coins -= that.misc.gold();
        global.kobold.stats.decreaseStat(StatsEnum.ENDURANCE, 1);
    }, function changeNote() {
        return global.ui.change.buildNotification([
            new Change("Spanked", "Health", -10),
            new Change("Humiliated", "Sanity", -30),
            new Change("Rear hurts", "Sexual exertion", +5, true),
            new Change("Money taken", "Gold", -that.misc.gold()),
            new Change("Sensitive behind", "Endurance", -1)
        ]);
    });

    this.hideStick = new ChangeController(id, "hideStick", function change() {
        global.kobold.status.mental.increase(10, "Outsmarting pursuers");
        global.kobold.inventory.equipment.strip(SlotEnum.WEAPON);
        global.kobold.stats.increaseStat(StatsEnum.INTELLIGENCE, 1);
    }, function changeNote() {
        return global.ui.change.buildNotification([
            new Change("Outsmarted pursuers", "Sanity", +10),
            new Change("Lost stick", global.kobold.inventory.createItemWithTooltip(that.misc.weapon(), true), -1),
            new Change("Smart move", "Intelligence", +1)
        ]);
    });

    this.runSucceed = new ChangeController(id, "runSucceed", function change() {

    }, function changeNote() {
        return global.ui.change.buildNotification([
            new Change("TODO", "CHANGE", +1)
        ]);
    });

    this.beg = new ChangeController(id, "beg", function change() {

    }, function changeNote() {
        return global.ui.change.buildNotification([
            new Change("TODO", "CHANGE", +1)
        ]);
    });

    this.hate = new ChangeController(id, "hate", function change() {

    }, function changeNote() {
        return global.ui.change.buildNotification([
            new Change("TODO", "CHANGE", +1)
        ]);
    });

    this.enjoy = new ChangeController(id, "enjoy", function change() {

    }, function changeNote() {
        return global.ui.change.buildNotification([
            new Change("TODO", "CHANGE", +1)
        ]);
    });

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};
}


