/**
 * Hide section of the woods.
 * @param {ForestController} controller The Forest controller.
 */
function ForestWoodsTreeFail(controller) {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;
    var ctrl = controller;

    var firstId = arguments.callee.name + "ButtonOne";
    var secondId = arguments.callee.name + "ButtonTwo";

    var firstChoice = new ForestWoodsHideSurrender(ctrl);
    var secondChoice = new ForestWoodsRun(ctrl);

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    /**
     * Builds and returns the content of this section.
     * @returns {string} The content.
     */
    function buildContent() {
        var weapon = ctrl.misc.weapon();
        var toReturn = `[p]
                            You frantically look around for the best tree to climb, yet sadly, [b]none[/b] of them seem to have [b]any[/b] low-hanging branches.
                            Not low enough for you to grab onto, at least.
                            Your best bet, or so you figure, is a large, sturdy looking oak tree with a medium-sized, moss-covered rock right next to it.
                            If you can use the outcrop to give you a boost, you [i]might[/i] just be able to reach high enough to grab an offshoot.
                        [/p]
                        [p]
                            After taking a few steps back, you [b]sprint[/b] towards the oak,
                            accelerating rapidly from standing still to [b]bolting[/b] as fast as you possibly can,
                            gaining momentum with every pace, your sharp claws [b]digging[/b] into the soft dirt below to propel you forwards.
                            Nearing the rock, you leap into the air as high as you can,
                            lifting off with just one foot so you can quickly place the other atop the mossy rock surface,
                            using it to launch yourself even higher.
                        [/p]
                        [p]
                            Alas, perhaps in part due to the added weight brought on by your ${global.kobold.inventory.createItemWithTooltip(weapon)},
                            you miss the branch you were aiming for by just an inch, your fingers scraping against the underside of it,
                            failing to find anything to hold on to.
                            You plummet to the ground, 
                            only barely managing to refrain from hurting yourself by gracefully turning your accumulated kinetic energy into an adept roll,
                            a move with which you surprise even yourself.
                        [/p]
                        [p]
                            Having landed on the ground safe and sound may have prevented you from painfully face-planting the dirt,
                            but you're not out of the woods yet.
                            The barking dog is speedily approaching, and it's far too late for you to find a new hiding spot.
                            You'll either have to come clean, surrender and hope they [b]won't[/b] carve you in half for what you've done,
                            or you can collect your wits and make them [b]work[/b] for their gold by hightailing it out of here as fast as you can.
                        [/p]`;
        return global.parser.parse(toReturn);
    }

    /**
     * Builds and returns the choice button.
     */
    function buildFirstChoice() {
        var disabled = ctrl.treeFail.has() ? "disabled" : "";
        var isSelected = ctrl.treeFail.get() === ForestWoodsTreeFailChoice.SURRENDER;
        var selected = isSelected ? "selected" : "";
        var button = `<button class="button inlinechoice ${selected}" id="${firstId}" ${disabled}>Surrender</button>`;

        var tooltip = global.parser.parse(`The jig is up. If you surrender, they might spare your life.`);
        var popupContainer = global.ui.makeToolTip(button, tooltip, false, false, "width: 160px;");
        // Re-wrap with proper positioning.
        button = `<div class="inlinechoice">`;
        button += popupContainer;
        button += `</div>`;

        return button;
    }

    /**
     * Builds and returns the choice button.
     */
    function buildSecondChoice() {
        var disabled = ctrl.treeFail.has() ? "disabled" : "";
        disabled = "disabled";
        var isSelected = ctrl.treeFail.get() === ForestWoodsTreeFailChoice.RUN;
        var selected = isSelected ? "selected" : "";
        var button = `<button class="button inlinechoice ${selected}" id="${secondId}" ${disabled}>Run</button>`;

        var tooltip = global.parser.parse(`They haven't caught you [i]yet[/i]. Leg it! <span class="todo">Unavailable.</span>`);
        var popupContainer = global.ui.makeToolTip(button, tooltip, false, false, "width: 150px;");
        // Re-wrap with proper positioning.
        button = `<div class="inlinechoice">`;
        button += popupContainer;
        button += `</div>`;

        return button;
    }

    /**
     * Builds and returns the choice of this section.
     * @returns {string} The choice of this section.
     */
    function buildChoice() {
        var choice = `<div class="choicecontainer"><div class="inlinechoiceheader">You: </div>`;
        choice += buildFirstChoice();
        choice += `<hr class="inlinechoiceseparator">`;
        choice += buildSecondChoice();
        choice += `</div>`;
        return choice;
    }

    /**
     * Disables all three buttons.
     */
    function disableButtons() {
        var buttons = [$("#" + firstId), $("#" + secondId)];
        buttons.forEach(function (button) {
            button.unbind();
            button.attr("disabled", true);
        });
    }

    /**
     * Loads and displays the next part.
     * @param {object} part Which part to load.
     */
    function loadNextPart(part) {
        var built = part.build(true);
        global.ui.appendBeforeFinisher(built, global.ui.genericHeaderId);
        $("#" + part.id).fadeIn(400);
        part.registerListeners();
    }

    /**
     * Adds a listener to the button.
     */
    function registerFirstListener() {
        $("#" + firstId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            ctrl.treeFail.set(ForestWoodsTreeFailChoice.SURRENDER);
            loadNextPart(firstChoice);
        });
    }

    /**
     * Adds a listener to the button.
     */
    function registerSecondListener() {
        $("#" + secondId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            ctrl.treeFail.set(ForestWoodsTreeFailChoice.RUN);
            loadNextPart(secondChoice);
        });
    }

    // PUBLIC MEMBERS \\        this.public = "test";
    this.id = arguments.callee.name;

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * Builds and returns this part.
     * @param {boolean} invisible If passed and true, will give the entire section a display:none style.
     */
    this.build = function (invisible) {
        var part = `<div id="${that.id}" ${invisible ? 'style="display:none;"' : ""}>`;
        part += buildContent();
        part += ctrl.treeFail.change();
        part += buildChoice();
        part += `</div>`;
        part += firstChoice.build();
        part += secondChoice.build();
        return part;
    };

    /**
     * Registers all the required button listeners for this part.
     */
    this.registerListeners = function () {
        firstChoice.registerListeners();
        secondChoice.registerListeners();

        if (ctrl.treeFail.has()) {
            return;
        }

        registerFirstListener();
        registerSecondListener();
    };
}

var ForestWoodsTreeFailChoice = {
    SURRENDER: 1,
    RUN: 2
};
