/**
 * Hide section of the woods.
 * @param {ForestController} controller The Forest controller.
 */
function ForestWoodsTree(controller) {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;
    var ctrl = controller;

    var firstId = arguments.callee.name + "ButtonOne";
    var secondId = arguments.callee.name + "ButtonTwo";

    var firstChoice = new ForestWoodsThrow(ctrl);
    var secondChoice = new ForestWoodsWeather(ctrl);

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    /**
     * Builds and returns the content of this section.
     * @returns {string} The content.
     */
    function buildContent() {
        var toReturn = `[p]
                            You frantically look around for the best tree to climb, yet sadly, [b]none[/b] of them seem to have [b]any[/b] low-hanging branches.
                            Not low enough for you to grab onto, at least.
                            Your best bet, or so you figure, is a large, firm looking oak tree with a medium-sized, moss-covered rock right next to it.
                            If you can use the outcrop to give you a boost, you [i]might[/i] just be able to reach high enough to grab an offshoot.
                        [/p]
                        [p]
                            After taking a few steps back, you [b]sprint[/b] towards the oak,
                            accelerating rapidly from standing still to [b]bolting[/b] as fast as you possibly can,
                            gaining momentum with every pace, your sharp claws [b]digging[/b] into the soft dirt below to propel you forwards.
                            Nearing the rock, you leap into the air as high as you can,
                            lifting off with just one foot so you can quickly place the other atop the mossy rock surface,
                            using it to launch yourself even higher.
                        [/p]
                        [p]
                            With the additional height gained from boosting off the rock,
                            you [b]barely[/b] manage to grab on to the top of the branch, inertia swinging your body forwards.
                            Once you've stabilized, you quickly pull yourself upwards, lifting your luckily not-all-too-heavy frame up onto the sturdy branch.
                            In retrospect, you're surprised you managed to jump high enough to reach, but you don't have much time to reflect upon your remarkable feat.
                        [/p]
                        [p]
                            You may be off the ground, but you're not in the clear yet.
                            It may have been a big leap for a kobold like you, but larger species can probably reach the branch you're on without even [b]trying[/b].
                            If you stay this low, you'll surely get noticed and caught.
                        [/p]
                        [p]
                            The barking dog nearing, you frantically begin to climb upwards, navigating branches and offshoots, scaling ever-higher.
                            By the time your pursuers come into view, you're high up above, several meters off the ground.
                            You press your body against the thick branch you end up on, concealing yourself as best as you can.
                            As the footsteps below come to an end, and the dog's barking turns to ominous growling,
                            you peek your head out to get a better idea of the situation.
                        [/p]
                        [p]
                            The party chasing you appears to consist of two men.
                            A human and a big, broad anthromorphic wolf.
                            As you suspected ages ago, they are accompanied by a feral guard dog doubling as a tracking hound.
                            The dog is scratching the tree you're in.
                            It clearly knows where you are, yet the ruffians accompanying it remain clueless.
                            You overhear their conversation.
                            "[color=red]Stupid dog.[/color]" "[color=gblue]Lizard can't have gone far. Let's look around.[/color]"
                        [/p]
                        [p]
                            Suddenly, you become aware of a slight [i]buzzing[/i] noise, soon followed by a tingling feeling on your forearm.
                            Tearing your attention away from your pursuers, you notice a large, fuzzy, black-and-yellow [b]bee[/b] sitting directly atop your exposed scales.
                            The motion of your head turning to face it must have scared the insect, because the moment it comes into view,
                            it [b]plunges[/b] down its hind-end, stabbing you with its stinger, which tears loose from the bee's abdomen,
                            sticking out from your scales like a poisoned dart would protrude from an assassin's victim.
                        [/p]
                        [p]
                            You barely manage to refrain from yelping in agony, instead letting out a small, hand-muffled grunt as pain begins to course through your arm.
                            The bee crawls along your scales for a few more inches, before dropping off the side, falling to the ground.
                            Dead.
                            You remove the barbed stinger, and discard it.
                            As the search party below begins to comb through the area, you realize where the annoying insect came from.
                            A honey-filled beehive hanging off the far-end of the very same branch you are on, more drones rapidly buzzing forth from it,
                            undoubtebly attracted by the alarm pheromone released by its singular vanguard.
                        [/p]
                        [p]
                            In other words: the bees are coming for you.
                        [/p]`;
        return global.parser.parse(toReturn);
    }

    /**
     * Builds and returns the choice button.
     */
    function buildFirstChoice() {
        var disabled = ctrl.tree.has() ? "disabled" : "";
        var isSelected = ctrl.tree.get() === ForestWoodsTreeChoice.THROW;
        var selected = isSelected ? "selected" : "";
        var button = `<button class="button inlinechoice ${selected}" id="${firstId}" ${disabled} style="width:160px;">Throw the nest</button>`;

        var tooltip = global.parser.parse(`Grab the hive and throw it at your pursuers. You might just be able to vanish in the ensuing panic.`);
        var popupContainer = global.ui.makeToolTip(button, tooltip, false, false, "width: 230px;");
        // Re-wrap with proper positioning.
        button = `<div class="inlinechoice" style="width: 160px;">`;
        button += popupContainer;
        button += `</div>`;

        return button;
    }

    /**
     * Builds and returns the choice button.
     */
    function buildSecondChoice() {
        var disabled = ctrl.tree.has() ? "disabled" : "";
        var isSelected = ctrl.tree.get() === ForestWoodsTreeChoice.WEATHER;
        var selected = isSelected ? "selected" : "";
        var button = `<button class="button inlinechoice ${selected}" id="${secondId}" ${disabled} style="width:190px;">Weather the stings</button>`;

        var tooltip = global.parser.parse(`Hang on for dear life and hope the men go away before the bees sting you [b]to death[/b].`);
        var popupContainer = global.ui.makeToolTip(button, tooltip, false, false, "width: 210px;");
        // Re-wrap with proper positioning.
        button = `<div class="inlinechoice" style="width:190px;">`;
        button += popupContainer;
        button += `</div>`;

        return button;
    }

    /**
     * Builds and returns the choice of this section.
     * @returns {string} The choice of this section.
     */
    function buildChoice() {
        var choice = `<div class="choicecontainer"><div class="inlinechoiceheader">You: </div>`;
        choice += buildFirstChoice();
        choice += `<hr class="inlinechoiceseparator">`;
        choice += buildSecondChoice();
        choice += `</div>`;
        return choice;
    }

    /**
     * Disables all three buttons.
     */
    function disableButtons() {
        var buttons = [$("#" + firstId), $("#" + secondId)];
        buttons.forEach(function (button) {
            button.unbind();
            button.attr("disabled", true);
        });
    }

    /**
     * Loads and displays the next part.
     * @param {object} part Which part to load.
     */
    function loadNextPart(part) {
        var built = part.build(true);
        global.ui.appendBeforeFinisher(built, global.ui.genericHeaderId);
        $("#" + part.id).fadeIn(400);
        part.registerListeners();
    }

    /**
     * Adds a listener to the button.
     */
    function registerFirstListener() {
        $("#" + firstId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            ctrl.tree.set(ForestWoodsTreeChoice.THROW);
            loadNextPart(firstChoice);
        });
    }

    /**
     * Adds a listener to the button.
     */
    function registerSecondListener() {
        $("#" + secondId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            ctrl.tree.set(ForestWoodsTreeChoice.WEATHER);
            loadNextPart(secondChoice);
        });
    }

    // PUBLIC MEMBERS \\        this.public = "test";
    this.id = arguments.callee.name;

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * Builds and returns this part.
     * @param {boolean} invisible If passed and true, will give the entire section a display:none style.
     */
    this.build = function (invisible) {
        var part = `<div id="${that.id}" ${invisible ? 'style="display:none;"' : ""}>`;
        part += buildContent();
        part += ctrl.tree.change();
        part += buildChoice();
        part += `</div>`;
        part += firstChoice.build();
        part += secondChoice.build();
        return part;
    };

    /**
     * Registers all the required button listeners for this part.
     */
    this.registerListeners = function () {
        firstChoice.registerListeners();
        secondChoice.registerListeners();

        if (ctrl.tree.has()) {
            return;
        }

        registerFirstListener();
        registerSecondListener();
    };
}

var ForestWoodsTreeChoice = {
    THROW: 1,
    WEATHER: 2
};
