/**
 * Initial bite section of the unknown scene.
 * @param {ForestController} controller The forest controller.
 */
function ForestUnknownInitialBite(controller) {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;
    var ctrl = controller;

    var continueId = "unknownInitialBiteContinueButton";

    var next = new ForestUnknownInitialBiteRape(ctrl);

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    /**
     * Builds and returns the content of this section.
     * @returns {string} The content.
     */
    function buildContent() {
        var toReturn = `[p]
                            Your mind races to come up with a [i]way out[/i].
                            You try to tug against the plant's grasp once more, but it simply won't budge, and you'll end up hurting yourself if you continue to resist it.
                            With the other spiked tentacles inching ever closer, you figure that if the tendril won't let go, you'll just have to [i]sever it[/i] instead.
                        [/p]
                        [p]
                            The organic terror may have restrained one of your wrists, but [b]not[/b] your head!
                            Steeling your resolve, you firmly yank your grasped arm back one final time.
                            The spikes around your wrist sink into your flesh, drawing a small amount of blood,
                            but the pain is a small price to pay for fully stretching the tendril,
                            preparing the rope-like plant part for a well-aimed [b]bite[/b].
                        [/p]
                        [p]
                            You lean forwards, bending over slightly just to [i]reach[/i] the tentacle.
                            Then, tilting your head to align your muzzle along the length of the organic barbed wire, you [b]chomp[/b] down on it,
                            your pointed teeth easily cutting through the plant matter, [b]tearing out[/b] a piece of the tendril.
                            While the now-amputated segment around your wrist instantly loses its grip and falls to the ground, your victory is short-lived.
                        [/p]
                        [p]
                            Before you even manage to retract your head once more, another of the plant's appendages takes advantage of your temporary vulnerable state.
                            It lashes out, leaping from the very ground all the way to your neck, tightly wrapping around your tender throat,
                            preventing you from pulling back, lest you rake open your own windpipe.
                            Panicking, you wildly flail your limbs in an attempt to sever your new [i]leash[/i],
                            yet instead of freedom, you only grow more constricted as your already bleeding wrist gets taken hold of anew,
                            and your one free arm, too, gets entangled by thorny vines.
                        [/p]
                        [p]
                            You kick your legs and squirm about as much as your bondage allows, in an attempt to free yourself still,
                            or at least to prevent the monster from grabbing your ankles.
                            Your writhing, while undoubtebly a hindrance, only serves to delay the inevitable.
                            After a few unsuccessful tries, the creature finally manages to grab your left leg by the calf,
                            and with your remaining mobility halved, it isn't long until your right leg, too, gets snagged.
                        [/p]
                        [p]
                            You try to struggle, yet no matter which part of your body you move, you end up getting hurt by the many thorns surrounding your every limb.
                            You growl loudly, voicing your impotent frustration.
                            Fear builds up in the back of your mind.
                            The thornbush calmly reinforces its grip on your arms, almost fully [b]encasing[/b] them in tendrils.
                            Your legs, too, become wrapped in prickly plant matter.
                            You are completely immobilized.
                            While you may have hurt the plant when you bit off one of its tendrils, it has seemingly won this conflict.
                        [/p]
                        [p]
                            Despite the pain, you continue to struggle for a good minute more, [b]desperate[/b] to escape the organic terror's clutches.
                            Using the grip on your neck, it [b]yanks[/b] your head further downwards, properly bending you over.
                            You don't stop testing your restraints until you notice a new development,
                            one which makes your heart skip a beat when you realize its implications.
                        [/p]
                        [p]
                            With your head forcibly pointed downwards, you get a good, 
                            up-close look at a different kind of tendril which snakes out from underneath the central mass of the animated bush.
                            A smooth, thornless, brightly colored, oddly phallic-shaped one which seems to be covered from tip to base in 
                            some kind of sickly sweet-smelling [i]goop[/i], slick enough to allow it to [i]slide[/i] over the forest floor towards your legs.
                            [i]Oh no.[/i]
                        [/p]`;
        return global.parser.parse(toReturn);
    }

    /**
     * Builds and returns the continue button.
     */
    function buildChoice() {
        var disabled = ctrl.unknown.pry.initbite.continued();
        var choice = `<div class="choicecontainer">
                        <button class="button inlinechoice ${disabled ? "selected" : ""}" id="${continueId}" ${disabled ? "disabled" : ""}>
                            Continue
                        </button>
                      </div>`;
        return choice;
    }
    
    /**
     * Disables all three buttons.
     */
    function disableButtons() {
        var buttons = [$("#" + continueId)];
        buttons.forEach(function (button) {
            button.unbind();
            button.attr("disabled", true);
        });
    }

    /**
     * Loads and displays the next part.
     * @param {object} part Which part to load.
     */
    function loadNextPart(part) {
        var built = part.build(true);
        global.ui.appendBeforeFinisher(built, global.ui.genericHeaderId);
        $("#" + part.id).fadeIn(400);
        part.registerListeners();
    }

    /**
     * Adds a listener to the button.
     */
    function registerContinueListener() {
        $("#" + continueId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            ctrl.unknown.pry.initbite.continue();
            loadNextPart(next);
        });
    }

    // PUBLIC MEMBERS \\        this.public = "test";
    this.id = "forestUnknownInitialBite";

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * Builds and returns this part.
     * @param {boolean} invisible If passed and true, will give the entire section a display:none style.
     */
    this.build = function (invisible) {
        if (ctrl.unknown.pry.base.get() !== ForestUnknownPryChoice.BITE) {
            return "";
        }
        var part = `<div id="${that.id}" ${invisible ? 'style="display:none;"' : ""}>`;
        part += buildContent();
        part += ctrl.unknown.pry.initbite.change();
        part += buildChoice();
        part += next.build();
        part += `</div>`;

        // BUILD CHILDREN HERE

        return part;
    };

    /**
     * Registers all the required button listeners for this part.
     */
    this.registerListeners = function () {
        if (ctrl.unknown.pry.base.get() !== ForestUnknownPryChoice.BITE) {
            return;
        }

        next.registerListeners();

        if (ctrl.unknown.pry.initbite.continued()) {
            return;
        }

        registerContinueListener();
    };
}
