/**
 * Confront section of the Farmer House scene.
 * @param {BreedingFarmController} controller The Farmer House controller.
 */
function FarmerHouseConfront(controller) {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;
    var ctrl = controller;

    var threatenId = arguments.callee.name + "ButtonOne";
    var intimidateId = arguments.callee.name + "ButtonTwo";
    var wrestleId = arguments.callee.name + "ButtonThree";

    var toThreaten = new FarmerHouseThreaten(ctrl);
    var toIntimidate = new FarmerHouseIntimidate(ctrl);
    var toWrestle = new FarmerHouseWrestle(ctrl);

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    /**
     * Builds and returns the content of this section.
     * @returns {string} The content.
     */
    function buildContent() {
        var toReturn = `[p]
                            Your mind races to come up with a solution to this [i]problem[/i].
                            You can't just leave the human be.
                            She's blocking your way into the rest of the house,
                            and if she keeps wandering about, she's bound to stumble upon you sooner or later.
                            If that happens, you're toast.
                            You decide it's best to take matters into your own hands.
                            That way, you might have a chance to stifle the woman's startled shouts instead of [i]you[/i] being the one getting surprised by [i]her[/i].
                        [/p]
                        [p]
                            You step out into the kitchen, approaching the housewife from behind.
                            She seems to be making ham sandwiches, likely the family's dinner.
                            Most human women you encounter wear dresses, but this one seems to be clothed a bit more [i]practical[/i].
                            She wears a plain, ragged linen top with torn sleeves, combined with what appears to be a home-made pair of leather pants.
                            Despite visibly being stitched together from various different pieces of animal hide,
                            the peasant-lady's trousers accentuate her form rather nicely.
                            While by no means young, she's far from [i]old[/i].
                            You'd wager her to be in her late thirties, perhaps early fourties.
                        [/p]
                        [p]
                            Suddenly, a floorboard creaks underneath your foot, alerting to the woman to your presence.
                            She turns around, at first looking [i]over[/i] you,
                            seemingly on the verge of returning to her duties before lowering her eyes,
                            her gaze falling directly ontop of the kobold standing in the middle of her kitchen.
                        [/p]
                        [p]
                            The woman's mouth drops agape.
                            She rubs her eyes to make sure she isn't dreaming.
                            Time itself seems to slow down as adrenaline begins to flood your body.
                            Your brain shoots into overdrive to try and formulate a plan of action that [i]doesn't[/i] entail you [b]running away[/b],
                            a primal urge to [i]flee[/i] building at the back of your head.
                        [/p]
                        [p]
                            On one hand, she's a human.
                            She's [i]much[/i] taller than you, and probably smarter, too.
                            Plus she lives here, which means she knows the layout of the house.
                            You don't.
                            A disadvantage, should this end in a chase.
                            On the other hand, she seems almost as scared as you were when she first entered the kitchen.
                            You [i]could[/i] try to threaten violence to keep her in line, or you could intimidate her in some other way.
                            A final possibility would be to [i]tackle[/i] the woman.
                            She may be twice your size, but that won't matter if you can force her to the floor.
                        [/p]`;
        return global.parser.parse(toReturn);
    }

    /**
     * Builds and returns the choice button.
     */
    function buildThreatenChoice() {
        var disabled = ctrl.confront.has() ? "disabled" : "";
        var isSelected = ctrl.confront.get() === FarmerHouseConfrontChoice.THREATEN;
        var selected = isSelected ? "selected" : "";
        var button = `<button class="button inlinechoice ${selected}" id="${threatenId}" ${disabled}>Threaten her</button>`;

        var tooltip = global.parser.parse(`Threaten the woman's life to keep her in check.`);
        var popupContainer = global.ui.makeToolTip(button, tooltip, false, false, "width: 180px;");
        // Re-wrap with proper positioning.
        button = `<div class="inlinechoice">`;
        button += popupContainer;
        button += `</div>`;

        return button;
    }

    /**
     * Builds and returns the choice button.
     */
    function buildIntimidateChoice() {
        var disabled = ctrl.confront.has() ? "disabled" : "";
        var isSelected = ctrl.confront.get() === FarmerHouseConfrontChoice.INTIMIDATE;
        var selected = isSelected ? "selected" : "";
        var button = `<button class="button inlinechoice ${selected}" id="${intimidateId}" ${disabled}>Intimidate her</button>`;

        var tooltip = global.parser.parse(`Shout loudly to inspire fear.`);
        var popupContainer = global.ui.makeToolTip(button, tooltip, false, false, "width: 130px;");
        // Re-wrap with proper positioning.
        button = `<div class="inlinechoice">`;
        button += popupContainer;
        button += `</div>`;

        return button;
    }

    /**
     * Builds and returns the choice button.
     */
    function buildWrestleChoice() {
        var disabled = ctrl.confront.has() ? "disabled" : "";
        var isSelected = ctrl.confront.get() === FarmerHouseConfrontChoice.WRESTLE;
        var selected = isSelected ? "selected" : "";
        var button = `<button class="button inlinechoice ${selected}" id="${wrestleId}" ${disabled}>Wrestle</button>`;

        var tooltip = global.parser.parse(`Tackle the human and wrestle her to the ground.`);
        var popupContainer = global.ui.makeToolTip(button, tooltip, false, false, "width: 180px;");
        // Re-wrap with proper positioning.
        button = `<div class="inlinechoice">`;
        button += popupContainer;
        button += `</div>`;

        return button;
    }

    /**
     * Builds and returns the choice of this section.
     * @returns {string} The choice of this section.
     */
    function buildChoice() {
        var choice = `<div class="choicecontainer"><div class="inlinechoiceheader">You loot: </div>`;
        choice += buildThreatenChoice();
        choice += `<hr class="inlinechoiceseparator">`;
        choice += buildIntimidateChoice();
        choice += `<hr class="inlinechoiceseparator">`;
        choice += buildWrestleChoice();
        choice += `</div>`;
        return choice;
    }

    /**
     * Disables all three buttons.
     */
    function disableButtons() {
        var buttons = [$("#" + threatenId), $("#" + intimidateId), $("#" + wrestleId)];
        buttons.forEach(function (button) {
            button.unbind();
            button.attr("disabled", true);
        });
    }

    /**
     * Loads and displays the next part.
     * @param {object} part Which part to load.
     */
    function loadNextPart(part) {
        var built = part.build(true);
        global.ui.appendBeforeFinisher(built, global.ui.genericHeaderId);
        $("#" + part.id).fadeIn(400);
        part.registerListeners();
    }

    /**
     * Adds a listener to the button.
     */
    function registerThreatenListener() {
        $("#" + threatenId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            ctrl.confront.set(FarmerHouseConfrontChoice.THREATEN);
            loadNextPart(toThreaten);
        });
    }

    /**
     * Adds a listener to the button.
     */
    function registerIntimidateListener() {
        $("#" + intimidateId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            ctrl.confront.set(FarmerHouseConfrontChoice.INTIMIDATE);
            loadNextPart(toIntimidate);
        });
    }

    /**
     * Adds a listener to the button.
     */
    function registerWrestleListener() {
        $("#" + wrestleId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            ctrl.confront.set(FarmerHouseConfrontChoice.WRESTLE);
            loadNextPart(toWrestle);
        });
    }

    // PUBLIC MEMBERS \\        this.public = "test";
    this.id = arguments.callee.name;

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * Builds and returns this part.
     * @param {boolean} invisible If passed and true, will give the entire section a display:none style.
     */
    this.build = function (invisible) {
        if (ctrl.arrival.get() !== FarmerHouseArrivalChoice.CONFRONT) {
            return "";
        }

        var part = `<div id="${that.id}" ${invisible ? 'style="display:none;"' : ""}>`;
        part += buildContent();
        part += buildChoice();
        part += `</div>`;
        part += toThreaten.build();
        part += toIntimidate.build();
        part += toWrestle.build();
        return part;
    };

    /**
     * Registers all the required button listeners for this part.
     */
    this.registerListeners = function () {
        if (ctrl.arrival.get() !== FarmerHouseArrivalChoice.CONFRONT) {
            return;
        }

        toThreaten.registerListeners();
        toIntimidate.registerListeners();
        toWrestle.registerListeners();

        if (ctrl.confront.has()) {
            return;
        }

        registerThreatenListener();
        registerIntimidateListener();
        registerWrestleListener();
    };
}

var FarmerHouseConfrontChoice = {
    THREATEN: 1,
    INTIMIDATE: 2,
    WRESTLE: 3
};

