/**
 * Confront section of the Farmer House scene.
 * @param {FarmerHouseController} controller The Farmer House controller.
 */
function FarmerHouseIntimidateFail(controller) {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;
    var ctrl = controller;

    var continueId = arguments.callee.name + "ButtonOne";

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    /**
     * Builds and returns the content of this section.
     * @returns {string} The content.
     */
    function buildContent() {
        var toReturn = `[p]
                            You rise to your tip-toes to seem as large and imposing as you possibly can,
                            before loudly and threateningly [b]shouting[/b] at the woman to [b]stay put[/b] and to [b]keep quiet[/b].
                            Despite your best efforts, you fail to appear very menacing.
                            The human seems unimpressed.
                            She reaches behind her, grabbing a rather sharp-looking ${global.kobold.inventory.createItemWithTooltip(new KitchenKnife)} from a wooden block.
                            [i]Oh no.[/i]
                        [/p]
                        [p]
                            The housewife menacingly advances upon you, knife in hand.
                            Every step she takes towards you, you take one backwards in fear.
                            Before long, you've been pushed back into the hallway you came from.
                            Unarmed, you could have easily taken her on, but with a knife [i]that big[/i],
                            she could [b]seriously[/b] hurt you, if not [b]kill you[/b] outright.
                        [/p]
                        [p]
                            Your fight or flight instincts kick in, and fighting a crazy lady armed with a sharp cutting tool is [b]not[/b] on your mind.
                            You spot the perfect opportunity to flee when the woman nearly trips over a crooked, protruding floorboard.
                            While she's busy recovering her balance, you turn tail and [b]bolt[/b] towards the rear exit.
                            As you open the door, the enraged human hurls her knife towards you,
                            the steel blade missing you by a hair, lodging itself into the wooden doorframe.
                        [/p]
                        [p]
                            For a moment, you consider retrieving the weapon and turning the tables on the housewife,
                            but the blade is stuck fast, and the woman lets out a shriek for help.
                            You decide to keep running, sprinting into the adjacent potato field.
                            A bunch of farmers emerge from their homes, rushing to the aid of the damsel in distress.
                            Luckily, by the time she's pointed out to them that you're escaping through the acreage,
                            you've already vanished into the small stretch of woodland on the opposite end.
                        [/p]
                        [p]
                            Despite having ditched your pursuers, you continue running all the way back to the eastern Varanar road.
                            The villagers might call the guards to investigate, and should anyone ask,
                            at least here you can [b]pretend[/b] to be a traveller instead of a [b]miserable failure[/b] of a thief.
                            Exhausted, you brace yourself against a nearby tree.
                        [/p]
                        [p]
                            You're glad you managed to get out of that one alive.
                            If you were a bit more intimidating and [b]persuasive[/b], perhaps your threatening appearance would have been taken a bit more serious.
                            Alas, what's done is done.
                            You can't win [i]every[/i] confrontation you get into, and at least you didn't get [b]caught[/b] or [b]cut[/b].
                            You've gained nothing, but you haven't lost much either, besides an opportunity.
                            Your newfound fear of kitchen knives is sure to vanish in due time.
                        [/p]
                        [p]
                            Your brief period of respite over, you continue on the way to Varanar.
                            Hopefully, the humans there will be less [i]ballsy[/i].
                            That's what the hamlet's inhabitants constantly claim, anyway.
                        [/p]`;
        return global.parser.parse(toReturn);
    }

    /**
     * Builds and returns the continue button.
     */
    function buildChoice() {
        var disabled = ctrl.continued();
        var choice = `<div class="choicecontainer">`;
        choice += `<button class="button bigbutton continuebutton" id="${continueId}" ${disabled ? "disabled" : ""}>`;
        choice += `Continue &gt;&gt`;
        choice += `</button>`;
        choice += `</div>`;
        return choice;
    }

    /**
     * Disables all three buttons.
     */
    function disableButtons() {
        var buttons = [$("#" + continueId)];
        buttons.forEach(function (button) {
            button.unbind();
            button.attr("disabled", true);
        });
    }

    /**
     * Loads and displays the next scene.
     * @param {string} sceneName Name of the scene to load.
     *  @param {string} folder Folder of the scene to load.
     */
    function loadNextPart(sceneName, folder) {
        global.ui.fadeOutContent(function () {
            global.sceneEnd();
            global.sceneLoader.loadScene(sceneName, folder);
        });
    }

    /**
     * Adds a listener to the button.
     */
    function registerContinueListener() {
        $("#" + continueId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            ctrl.continue();
            loadNextPart(ctrl.varanarSceneName, ctrl.varanarFolderName);
        });
    }

    // PUBLIC MEMBERS \\        this.public = "test";
    this.id = arguments.callee.name;

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * Builds and returns this part.
     * @param {boolean} invisible If passed and true, will give the entire section a display:none style.
     */
    this.build = function (invisible) {
        global.kobold.history.shared.farmerhouse.failed = true;
        global.ui.applyTheme("hamlet_day");
        var part = `<div id="${that.id}" ${invisible ? 'style="display:none;"' : ""}>`;
        part += buildContent();
        part += ctrl.intimidateFail();
        part += buildChoice();
        part += `</div>`;
        return part;
    };

    /**
     * Registers all the required button listeners for this part.
     */
    this.registerListeners = function () {
        if (ctrl.continued()) {
            return;
        }

        registerContinueListener();
    };
}
