/**
 * Confront section of the Farmer House scene.
 * @param {FarmerHouseController} controller The Farmer House controller.
 */
function FarmerHouseTiedUp(controller) {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;
    var ctrl = controller;

    var lootId = arguments.callee.name + "ButtonOne";
    var rapeId = arguments.callee.name + "ButtonTwo";

    var toLoot = new FarmerHouseFullLoot(ctrl);
    var toRape = new FarmerHouseTiedUpRape(ctrl);

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    /**
     * Builds and returns the content of this section.
     * @returns {string} The content.
     */
    function buildContent() {
        var toReturn = `[p]
                            The woman may be pacified, for now, but you still don't trust her.
                            You can [i]sense[/i] that she's just [b]waiting[/b] for you to slip up,
                            for you to turn your back so she can [b]plunge a knife[/b] into it.
                            Luckily, you brought just the right tool to deal with these kinds of situations.
                        [/p]
                        [p]
                            You produce your rope.
                            After telling the human to [b]stay down[/b], you slowly advance upon her.
                            You crudely [b]grab[/b] both her arms, and loop your rope around her wrists.
                            Forcing the meek woman to the ground, you then firmly bind her ankles,
                            looping the cord around her legs multiple times.
                            As a finishing touch, you wind the rope upwards, and spin it around her head to cover her mouth,
                            preventing her from screaming for help while completely immobilizing the housewife.
                        [/p]
                        [p]
                            After tying a firm knot, you rise to your feet and admire your handiwork.
                            The human struggles fiercely against her restraints, wriggling her body back and forth in a vain attempt to escape the well-tied rope.
                            She tries pleading with you through her improvised gag,
                            but all that escapes her lips are a bunch of muffled, high-pitched tones
                            barely even resembling the ever more frustrated and desperate implorations she had in mind.
                        [/p]
                        [p]
                            It looks like you did an excellent job.
                            She can't move, she can't scream for help, and the house is all yours now.
                            But then again: she [b]can't move[/b] and she [b]can't scream for help[/b].
                            You could very easily do something [i]other[/i] than stealing things.
                        [/p]`;
        return global.parser.parse(toReturn);
    }

    /**
     * Builds and returns the choice button.
     */
    function buildLootChoice() {
        var disabled = ctrl.tied.has() ? "disabled" : "";
        var isSelected = ctrl.tied.get() === FarmerHouseTiedUpChoice.LOOT;
        var selected = isSelected ? "selected" : "";
        var button = `<button class="button inlinechoice ${selected}" id="${lootId}" ${disabled}>Loot</button>`;

        var tooltip = global.parser.parse(`With the human restrained, you can loot in peace.`);
        var popupContainer = global.ui.makeToolTip(button, tooltip, false, false, "width: 140px;");
        // Re-wrap with proper positioning.
        button = `<div class="inlinechoice">`;
        button += popupContainer;
        button += `</div>`;

        return button;
    }

    /**
     * Builds and returns the choice button.
     */
    function buildRapeChoice() {
        var disabled = ctrl.tied.has() ? "disabled" : "";
        var isSelected = ctrl.tied.get() === FarmerHouseTiedUpChoice.RAPE;
        var selected = isSelected ? "selected" : "";
        var button = `<button class="button inlinechoice ${selected}" id="${rapeId}" ${disabled}>Fuck her</button>`;

        var tooltip = global.parser.parse(`Have your way with the woman. She's completely restrained, and thus unable to fight back.`);
        var popupContainer = global.ui.makeToolTip(button, tooltip, false, false, "width: 180px;");
        // Re-wrap with proper positioning.
        button = `<div class="inlinechoice">`;
        button += popupContainer;
        button += `</div>`;

        return button;
    }

    /**
     * Builds and returns the choice of this section.
     * @returns {string} The choice of this section.
     */
    function buildChoice() {
        var choice = `<div class="choicecontainer"><div class="inlinechoiceheader">You: </div>`;
        choice += buildRapeChoice();
        choice += `<hr class="inlinechoiceseparator">`;
        choice += buildLootChoice();
        choice += `</div>`;
        return choice;
    }

    /**
     * Disables all three buttons.
     */
    function disableButtons() {
        var buttons = [$("#" + lootId), $("#" + rapeId)];
        buttons.forEach(function (button) {
            button.unbind();
            button.attr("disabled", true);
        });
    }

    /**
     * Loads and displays the next part.
     * @param {object} part Which part to load.
     */
    function loadNextPart(part) {
        var built = part.build(true);
        global.ui.appendBeforeFinisher(built, global.ui.genericHeaderId);
        $("#" + part.id).fadeIn(400);
        part.registerListeners();
    }

    /**
     * Adds a listener to the button.
     */
    function registerLootListener() {
        $("#" + lootId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            ctrl.tied.set(FarmerHouseTiedUpChoice.LOOT);
            loadNextPart(toLoot);
        });
    }

    /**
     * Adds a listener to the button.
     */
    function registerRapeListener() {
        $("#" + rapeId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            ctrl.tied.set(FarmerHouseTiedUpChoice.RAPE);
            loadNextPart(toRape);
        });
    }

    // PUBLIC MEMBERS \\        this.public = "test";
    this.id = arguments.callee.name;

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * Builds and returns this part.
     * @param {boolean} invisible If passed and true, will give the entire section a display:none style.
     */
    this.build = function (invisible) {
        if (ctrl.scared.get() !== FarmerHouseScaredChoice.TIE) {
            return "";
        }

        var part = `<div id="${that.id}" ${invisible ? 'style="display:none;"' : ""}>`;
        part += buildContent();
        part += ctrl.removeRope();
        part += buildChoice();
        part += `</div>`;
        part += toLoot.build();
        part += toRape.build();
        return part;
    };

    /**
     * Registers all the required button listeners for this part.
     */
    this.registerListeners = function () {
        if (ctrl.scared.get() !== FarmerHouseScaredChoice.TIE) {
            return;
        }

        toLoot.registerListeners();
        toRape.registerListeners();

        if (ctrl.tied.has()) {
            return;
        }

        registerLootListener();
        registerRapeListener();
    };
}

var FarmerHouseTiedUpChoice = {
    LOOT: 1,
    RAPE: 2
};
