/**
 * Arrival section of Varanar, Night Two.
 * @param {NightTwoController} controller The Night Two controller.
 */
function NightTwoStage(controller) {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;
    var ctrl = controller;

    var continueId = arguments.callee.name + "ButtonOne";
    var next = new NightTwoRunIn(ctrl);

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    /**
     * Builds and returns the content of this section.
     * @returns {string} The content.
     */
    function buildContent() {
        var toReturn = `[p]
                            After passing the gate, you are greeted with the sight of Varanar's grand avenue,
                            a single road leading all the way from the eastern entrance to the massive town square.
                            Last time you were in town, you tried pickpocketing people on this very path during the bustling morning rush.
                            Now, the streets are nigh-empty, save for a few patrolling guardsmen.
                        [/p]
                        [p]
                            You idlemindedly walk down the road towards the market square.
                            The tall, human-made buildings on either side almost make you feel a little [i]claustrophobic[/i],
                            despite the street being wide enough to fit several carts side-by-side.
                            To you, this entire city seems like a bit of a [i]miracle[/i].
                            You can't even [b]begin[/b] to imagine the [b]huge[/b] amount of work it must have taken to build all of this.
                            While other races are banding together to construct vast cities,
                            your kind can barely stand one another for long enough to rob people together.
                        [/p]
                        [p]
                            After a brief hike, you arrive at the town square.
                            While the plaza is empty at the moment, the bi-weekly market has left a clear impression on the land.
                            You wouldn't call it completely riddled with garbage, but there is more than a bit of litter remaining.
                            The hard, near-frozen ground is completely [b]trampled[/b], a multitude of holes denoting the former position of the stalls.
                        [/p]
                        [p]
                            Suppressing your natural urge to sift through the trash, you walk up to the small stage on the far-end of the square.
                            This is where important decrees are shared, where traitors are hung,
                            where stockades are set and where prestigious travelling shows entertain thousands of people.
                            But right now, for you, it is nothing but a place to rest your weary feet at.
                            You crawl up onto the wooden surface, and sit yourself down on the edge.
                        [/p]
                        [p]
                            The church bells ring midnight.
                            You take in a deep breath of cool evening air, staring upwards at the night sky.
                            Stars twinkle back at your inquisitive gaze, mirroring the sparkle in your eyes.
                            While not full moon yet, it will be in a couple of days.
                            There's something magical about this city.
                            It makes you feel [i]safe[/i].
                            Moreso than the forest, at least.
                        [/p]
                        [p]
                            [sneak]
                                You are in a safe zone.
                                You can use items from your inventory here.
                                It may be wise to prepare yourself for the trials up ahead,
                                lest you be found wanting.
                            [/sneak]
                        [/p]`;

        return global.parser.parse(toReturn);
    }

    /**
     * Builds and returns the choice button.
     */
    function buildNextChoice() {
        var disabled = ctrl.stage.continued() ? "disabled" : "";
        var isSelected = ctrl.stage.continued();
        var selected = isSelected ? "selected" : "";
        var button = `<button class="button inlinechoice ${selected}" id="${continueId}" ${disabled}>Continue</button>`;
        return button;
    }

    /**
     * Builds and returns the choice of this section.
     * @returns {string} The choice of this section.
     */
    function buildChoice() {
        var choice = `<div class="choicecontainer">`;
        choice += buildNextChoice();
        choice += `</div>`;
        return choice;
    }

    /**
     * Disables all three buttons.
     */
    function disableButtons() {
        var buttons = [$("#" + continueId)];
        buttons.forEach(function (button) {
            button.unbind();
            button.attr("disabled", true);
        });
    }

    /**
     * Loads and displays the next part.
     * @param {object} part Which part to load.
     */
    function loadNextPart(part) {
        var built = part.build(true);
        global.ui.appendBeforeFinisher(built, global.ui.genericHeaderId);
        $("#" + part.id).fadeIn(400);
        part.registerListeners();
    }

    /**
     * Adds a listener to the button.
     */
    function registerNextListener() {
        $("#" + continueId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            ctrl.stage.continue();
            loadNextPart(next);
        });
    }

    // PUBLIC MEMBERS \\        this.public = "test";
    this.id = arguments.callee.name;

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * Builds and returns this part.
     * @param {boolean} invisible If passed and true, will give the entire section a display:none style.
     */
    this.build = function (invisible) {
        if (!ctrl.arrival.continued()) {
            return "";
        }
        global.ui.applyTheme("varanar_night"); // Fix theme when reverting
        global.ui.imageBackground.show("scenes/Varanar/NightTwo/arrival/stars.gif");
        global.kobold.inventory.safeZone = true;
        var part = `<div id="${that.id}" ${invisible ? 'style="display:none;"' : ""}>`;
        part += buildContent();
        part += buildChoice();
        part += `</div>`;
        part += next.build();
        return part;
    };

    /**
     * Registers all the required button listeners for this part.
     */
    this.registerListeners = function () {
        if (!ctrl.arrival.continued()) {
            return;
        }

        next.registerListeners();

        if (ctrl.stage.continued()) {
            return;
        }

        registerNextListener();
    };
}
