/**
 * Fleeing section of Varanar, Night Two.
 * @param {NightTwoController} controller The Night Two controller.
 */
function NightTwoFlee(controller) {
    // PRIVATE MEMBERS \\       var private = "test";
    var that = this;
    var ctrl = controller;

    var runId = arguments.callee.name + "ButtonOne";
    var hideId = arguments.callee.name + "ButtonTwo";

    var toRun = new NightTwoKeepRunning(ctrl);
    var toHide = new NightTwoAlley(ctrl);

    // PRIVATE FUNCTIONS \\     function privateFunction(){}

    /**
     * Builds and returns the content of this section.
     * @returns {string} The content.
     */
    function buildContent() {
        var toReturn = `[p]
                            You wisely decide to head the [i]other[/i] way, which unfortunately leads you back into the [i]brothel district[/i].
                            You aren't sure yet whether they're actually [i]following[/i] you or not, but the men seem to be heading this way as well.
                            They're getting more [b]rowdy[/b] by the minute.
                            You vaguely overhear them cracking rude jokes about...[i]kobolds[/i].
                            To be more precise: they're joking [b]about you[/b].
                            And the things they're saying are far from being nice.
                            While jolly at first, the mood is growing more grim with every passing second.
                        [/p]
                        [p]
                            To see whether you're just a victim of bad luck, or if the group is actively [i]chasing[/i] you,
                            you take a few random turns to nowhere in particular.
                            Still, the men remain on your tail.
                            Like they have some unsettled beef with you, or maybe with your kind as a whole.
                            You pick up your walking pace.
                            So do they.
                            You start jogging.
                            They resort to drunkenly and menacingly speedwalking,
                            their size allowing them to keep up with your relatively higher pace without needing to [i]run[/i].
                        [/p]
                        [p]
                            Your mind is racing a million miles an hour.
                            You feel anxious.
                            Like a rat trapped in a maze, pursued by bunch of hungry cats.
                            The men seem to be gaining on you, despite your best efforts.
                            If you don't do something quick, they'll catch you.
                            And who knows what a gang of angry, drunken humans'll do once they get their hands on a dirty kobold thief like yourself?
                        [/p]`;
        return global.parser.parse(toReturn);
    }

    /**
     * Builds and returns the choice button.
     */
    function buildRunChoice() {
        var disabled = ctrl.flee.has() ? "disabled" : "";
        var isSelected = ctrl.flee.get() === NightTwoFleeChoice.RUN;
        var selected = isSelected ? "selected" : "";
        var button = `<button class="button inlinechoice ${selected}" id="${runId}" ${disabled}>Run</button>`;

        var tooltip = global.parser.parse(`Run away as fast as you can. Hope they won't be able to keep up.`);
        var popupContainer = global.ui.makeToolTip(button, tooltip, false, false, "width: 180px;");
        // Re-wrap with proper positioning.
        button = `<div class="inlinechoice">`;
        button += popupContainer;
        button += `</div>`;

        return button;
    }

    /**
     * Builds and returns the choice button.
     */
    function buildHideChoice() {
        var disabled = ctrl.flee.has() ? "disabled" : "";
        var isSelected = ctrl.flee.get() === NightTwoFleeChoice.HIDE;
        var selected = isSelected ? "selected" : "";
        var button = `<button class="button inlinechoice ${selected}" id="${hideId}" ${disabled}>Hide</button>`;

        var tooltip = global.parser.parse(`Dart into a nearby alleyway and pray they don't find you.`);
        var popupContainer = global.ui.makeToolTip(button, tooltip, false, false, "width: 180px;");
        // Re-wrap with proper positioning.
        button = `<div class="inlinechoice">`;
        button += popupContainer;
        button += `</div>`;

        return button;
    }

    /**
     * Builds and returns the choice of this section.
     * @returns {string} The choice of this section.
     */
    function buildChoice() {
        var choice = `<div class="choicecontainer"><div class="inlinechoiceheader">You: </div>`;
        choice += buildRunChoice();
        choice += `<hr class="inlinechoiceseparator">`;
        choice += buildHideChoice();
        choice += `</div>`;
        return choice;
    }

    /**
     * Disables all three buttons.
     */
    function disableButtons() {
        var buttons = [$("#" + runId), $("#" + hideId)];
        buttons.forEach(function (button) {
            button.unbind();
            button.attr("disabled", true);
        });
    }

    /**
     * Loads and displays the next part.
     * @param {object} part Which part to load.
     */
    function loadNextPart(part) {
        var built = part.build(true);
        global.ui.appendBeforeFinisher(built, global.ui.genericHeaderId);
        $("#" + part.id).fadeIn(400);
        part.registerListeners();
    }

    /**
     * Adds a listener to the button.
     */
    function registerRunListener() {
        $("#" + runId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            ctrl.flee.set(NightTwoFleeChoice.RUN);
            loadNextPart(toRun);
        });
    }

    /**
     * Adds a listener to the button.
     */
    function registerHideListener() {
        $("#" + hideId).click(function () {
            $(this).addClass("selected");
            disableButtons();
            ctrl.flee.set(NightTwoFleeChoice.HIDE);
            loadNextPart(toHide);
        });
    }

    // PUBLIC MEMBERS \\        this.public = "test";
    this.id = arguments.callee.name;

    // PUBLIC FUNCTIONS \\      this.publicFunction = function(){};

    /**
     * Builds and returns this part.
     * @param {boolean} invisible If passed and true, will give the entire section a display:none style.
     */
    this.build = function (invisible) {
        if (ctrl.runin.get() !== NightTwoRunInChoice.FLEE) {
            return "";
        }

        var part = `<div id="${that.id}" ${invisible ? 'style="display:none;"' : ""}>`;
        part += buildContent();
        part += ctrl.flee.change();
        part += buildChoice();
        part += `</div>`;
        part += toRun.build();
        part += toHide.build();
        return part;
    };

    /**
     * Registers all the required button listeners for this part.
     */
    this.registerListeners = function () {
        if (ctrl.runin.get() !== NightTwoRunInChoice.FLEE) {
            return;
        }

        toRun.registerListeners();
        toHide.registerListeners();

        if (ctrl.flee.has()) {
            return;
        }

        registerRunListener();
        registerHideListener();
    };
}

var NightTwoFleeChoice = {
    RUN: 1,
    HIDE: 2
};

